@@ -15,9 +15,20 @@
 # specific language governing permissions and limitations
 # under the License.
 
+# Wrap testthat::test_that with a check for the C++ library
+options(..skip.tests = !arrow::arrow_available())
+
 test_that <- function(what, code) {
   testthat::test_that(what, {
-    skip_if(!arrow::arrow_available(), "arrow C++ library not available")
+    skip_if(getOption("..skip.tests", TRUE), "arrow C++ library not available")
     code
   })
 }
+
+# Wrapper to run tests that only touch R code even when the C++ library isn't
+# available (so that at least some tests are run on those platforms)
+r_only <- function(code) {
+  old <- options(..skip.tests = FALSE)
+  on.exit(options(old))
+  code
+}
